summaryrefslogtreecommitdiff
path: root/libraries/ghc-prim
diff options
context:
space:
mode:
authorSylvain Henry <sylvain@haskus.fr>2020-04-05 17:25:06 +0200
committerSylvain Henry <sylvain@haskus.fr>2020-04-18 20:04:14 +0200
commit3ca52151881451ce5b3a7740d003e811b586140d (patch)
tree2dda7d3796d300063111460929489e146701522c /libraries/ghc-prim
parent15ab6cd548f284732a7f89d78c2b89b1bfc4ea1d (diff)
downloadhaskell-3ca52151881451ce5b3a7740d003e811b586140d.tar.gz
GHC.Core.Opt renaming
* GHC.Core.Op => GHC.Core.Opt * GHC.Core.Opt.Simplify.Driver => GHC.Core.Opt.Driver * GHC.Core.Opt.Tidy => GHC.Core.Tidy * GHC.Core.Opt.WorkWrap.Lib => GHC.Core.Opt.WorkWrap.Utils As discussed in: * https://mail.haskell.org/pipermail/ghc-devs/2020-April/018758.html * https://gitlab.haskell.org/ghc/ghc/issues/13009#note_264650
Diffstat (limited to 'libraries/ghc-prim')
-rw-r--r--libraries/ghc-prim/GHC/CString.hs8
1 files changed, 4 insertions, 4 deletions
diff --git a/libraries/ghc-prim/GHC/CString.hs b/libraries/ghc-prim/GHC/CString.hs
index 3ae4d50532..8c0d272a67 100644
--- a/libraries/ghc-prim/GHC/CString.hs
+++ b/libraries/ghc-prim/GHC/CString.hs
@@ -46,7 +46,7 @@ is a waste.
Moreover, inlining early may interfere with a variety of rules that are supposed
to match unpackCString#,
* BuiltInRules in GHC.Core.Op.ConstantFold; e.g.
eqString (unpackCString# (Lit s1)) (unpackCString# (Lit s2)
= s1 == s2
@@ -60,8 +60,8 @@ to match unpackCString#,
Moreover, we want to make it CONLIKE, so that:
-* the rules in GHC.Core.Op.ConstantFold will fire when the string is let-bound.
- E.g. the eqString rule in GHC.Core.Op.ConstantFold
+* the rules in GHC.Core.Opt.ConstantFold will fire when the string is let-bound.
+ E.g. the eqString rule in GHC.Core.Opt.ConstantFold
eqString (unpackCString# (Lit s1)) (unpackCString# (Lit s2) = s1==s2
* exprIsConApp_maybe will see the string when we have
@@ -115,7 +115,7 @@ unpackFoldrCString# :: Addr# -> (Char -> a -> a) -> a -> a
-- Usually the unpack-list rule turns unpackFoldrCString# into unpackCString#
--- It also has a BuiltInRule in GHC.Core.Op.ConstantFold:
+-- It also has a BuiltInRule in GHC.Core.Opt.ConstantFold:
-- unpackFoldrCString# "foo" c (unpackFoldrCString# "baz" c n)
-- = unpackFoldrCString# "foobaz" c n
@@ -46,7 +46,7 @@ is a waste.
Moreover, inlining early may interfere with a variety of rules that are supposed
to match unpackCString#,
- * BuiltInRules in GHC.Core.Op.ConstantFold; e.g.
+ * BuiltInRules in GHC.Core.Opt.ConstantFold; e.g.
eqString (unpackCString# (Lit s1)) (unpackCString# (Lit s2)
= s1 == s2